@@ -288,6 +288,10 @@ class SurfingEntrance(object):
         wechat_bot = WechatBot()
         wechat_bot.send_data_update_status(yesterday, 'PART-II', failed_tasks, updated_count)
 
+        from .data.fund.data_check.data_checker import DataChecker
+        dc = DataChecker()
+        dc.process()
+
     def data_update_miscs(self):
         from .data.api.raw import RawDataApi
         yesterday = self._get_yesterday()
@@ -678,7 +682,7 @@ class SurfingEntrance(object):
             wechat_bot = WechatBot()
 
         # TODO: 目前这里是hard code的
-        obj_keys = {'高瓴': '^.*高瓴|天津礼仁|珠海赫成.*$'}
+        obj_keys = {'高瓴': '^.*高瓴|天津礼仁|珠海赫成|中国价值基金.*$'}
         for key, obj in obj_keys.items():
             df_one = df[df.issue_object.str.contains(obj)]
             if df_one.empty:
@@ -707,7 +711,7 @@ class SurfingEntrance(object):
             wechat_bot = WechatBot()
 
         # TODO: 目前这里是hard code的
-        obj_keys = {'高瓴': '^.*高瓴|天津礼仁|珠海赫成.*$'}
+        obj_keys = {'高瓴': '^.*高瓴|天津礼仁|珠海赫成|中国价值基金.*$'}
         for key, obj in obj_keys.items():
             df_one = df[df.issue_object.str.contains(obj)]
             if df_one.empty:
