@@ -1062,6 +1062,30 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_hedge_fund_custodian_data <err_msg> {e} from {HedgeFundCustodianData.__tablename__}')
 
+    def get_pf_indicator(self, pf_id_list:Tuple[str], start_date:str='', end_date:str=''):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    PfIndicator,
+                )
+                if pf_id_list:
+                    query = query.filter(
+                        PfIndicator.pf_id.in_(pf_id_list),
+                    )
+                if start_date:
+                    query = query.filter(
+                        PfIndicator.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        PfIndicator.datetime <= end_date,
+                    )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print(f'failed to get_pf_indicator <err_msg> {e} from {PfIndicator.__tablename__}')
+
+            
     def delete_hedge_fund_custodian_data(self, manager_id: str, fof_id: str, datetime) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
