@@ -1425,12 +1425,12 @@ class PortfolioDataApi(metaclass=Singleton):
             asset_info = asset_info.append(_df).drop_duplicates('real_id')
             result = []
             real_ids = product_list
-            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=begin_date,end_date=end_date)
+            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=begin_date,end_date=end_date).dropna(subset=['nav'])
             if not _df1.empty > 0:
                 _df1 = _df1.pivot_table(index='datetime',columns='fund_id',values='nav')
-            _df2 = derived.get_fof_nav(manager_id=manager_id, fof_id_list=real_ids)
+            _df2 = derived.get_fof_nav(manager_id=manager_id, fof_id_list=real_ids).dropna(subset=['adjusted_nav'])
             if not _df2.empty > 0:
-                _df2 = _df2.pivot_table(index='datetime',columns='fof_id',values='adjusted_nav')
+                _df2 = _df2.pivot_table(index='datetime',columns='fof_id',values='adjusted_nav').loc[begin_date:end_date]
                 if not _df1.empty:
                     _df = _df1.append(_df2)
                     res = []
@@ -1591,10 +1591,10 @@ class PortfolioDataApi(metaclass=Singleton):
                     name_dic[k] = v
             result = []
             real_ids = product_list
-            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20090101')
+            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20090101').dropna(subset=['nav'])
             if not _df1.empty > 0:
                 _df1 = _df1.pivot_table(index='datetime',columns='fund_id',values='nav')
-            _df2 = derived.get_fof_nav(manager_id=manager_id, fof_id_list=real_ids)
+            _df2 = derived.get_fof_nav(manager_id=manager_id, fof_id_list=real_ids).dropna(subset=['adjusted_nav'])
             if not _df2.empty > 0:
                 _df2 = _df2.pivot_table(index='datetime',columns='fof_id',values='adjusted_nav')
                 if not _df1.empty:
@@ -1623,7 +1623,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 _df = _df1.copy() 
             data_dic = {
                 'name_dic':name_dic,
-                'result':_df,
+                'result':[_df],
             }
             return data_dic
         except Exception as e:
