@@ -69,7 +69,7 @@ class FundAlphaProcessor:
                                        & (self.fund_info.structure_type <= 1)
                                        & (~self.fund_info.wind_class_2.isnull())]
         # 基金净值数据、指数价格数据的index对齐到交易日列表
-        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date, end_date)  #, fund_list = f_l)
+        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date=start_date, end_date=end_date)  #, fund_list = f_l)
         self._fund_nav: pd.DataFrame = fund_nav.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').reindex(self._trading_days.index).fillna(method='ffill')
         # 排除掉异常净值基金
         res = []
@@ -262,4 +262,4 @@ class FundAlphaProcessor:
 
 if __name__ == '__main__':
     fap = FundAlphaProcessor(DerivedDataHelper())
-    fap.process('20200925', '20200925')
\ No newline at end of file
+    fap.process('20210624', '20210624')
