@@ -133,7 +133,7 @@ class HedgeFundDataManager(metaclass=Singleton):
                         # 水位线变成本次计提时的水位线了
                         one['water_line'] = row.acc_unit_value
                 elif fof_info.incentive_fee_mode in (FOFIncentiveFeeMode.INTE_HIGH_WL, FOFIncentiveFeeMode.INTE_HIGH_WL_WITH_SCST_R):
-                    assert row.water_line > last_water_line, '!!!'
+                    assert row.water_line > last_water_line, f'water line should be increased monotonously for every investor (manager_id){manager_id} (fof_id){fof_id} (investor_id){investor_id} (last water line){last_water_line} (water line this time){row.water_line}'
                     # profit = self._calc_carry(row.acc_unit_value, last_water_line, fof_info.incentive_fee_type, fof_info.incentive_fee_str)
                 else:
                     assert False, f'do not support the fee mode {fof_info.incentive_fee_mode} temp (fof_id){fof_id} (manager_id){manager_id}'
@@ -225,6 +225,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             raise ValueError(f'invalid event_type {event_type}')
 
         _, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['datetime'], datas['investor_id'], exclude1=[datas['id']] if 'id' in datas else [])
+
         datas['share_changed'] = round(datas['share_changed'], 2)
         try:
             datas['share_after_trans'] = round(float(share_separate.at[datas['investor_id'], 'share_changed']) + datas['share_changed'], 2)
