@@ -4,6 +4,7 @@ import datetime
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME, SMALLINT
+from sqlalchemy.sql.sqltypes import INTEGER
 
 from ...constant import StockFactorType, IndClassType, HoldingAssetType
 
@@ -902,3 +903,91 @@ class HedgeFundCustodianData(FOFBase):
     mutual_funds_data = Column(TEXT)  # 持仓公募信息
     hedge_funds_data = Column(TEXT)  # 持仓私募信息
     url = Column(CHAR(127))  # 
+
+class PfIndicator(Base):
+    '''基金评价指标'''
+
+    __tablename__ = 'pf_indicator'
+    pf_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    period = Column(CHAR(10), primary_key=True) # 因子计算时间范围
+
+    start_date =Column(DATE) # 开始日
+    last_unit_nav = Column(DOUBLE(asdecimal=False)) # 末期单位净值
+    annualized_ret = Column(DOUBLE(asdecimal=False)) # 年化收益
+    trade_year = Column(DOUBLE(asdecimal=False)) # 成立年限
+    cumu_ret = Column(DOUBLE(asdecimal=False)) # 累计收益
+    annualized_vol = Column(DOUBLE(asdecimal=False)) # 年化波动率
+    sharpe = Column(DOUBLE(asdecimal=False)) # 夏普率
+    recent_year_ret = Column(DOUBLE(asdecimal=False)) # 最近自然年收益
+    recent_1w_ret = Column(DOUBLE(asdecimal=False)) # 最近1周收益
+    recent_1m_ret = Column(DOUBLE(asdecimal=False)) # 最近1月收益
+    recent_4w_ret = Column(DOUBLE(asdecimal=False)) # 最近4周收益
+    recent_3m_ret = Column(DOUBLE(asdecimal=False)) # 最近3月收益
+    recent_6m_ret = Column(DOUBLE(asdecimal=False)) # 最近6月收益
+    y_2020_ret = Column(DOUBLE(asdecimal=False)) # 2020年收益
+    last_year_ret = Column(DOUBLE(asdecimal=False)) # 去年收益
+    recent_y1_ret = Column(DOUBLE(asdecimal=False)) # 近一年收益
+    recent_y3_ret = Column(DOUBLE(asdecimal=False)) # 近三年收益
+    recent_y5_ret = Column(DOUBLE(asdecimal=False)) # 近五年收益
+    mdd = Column(DOUBLE(asdecimal=False)) # 最大回撤
+    mdd_date1 = Column(DATE) # 最大回撤开始时间
+    mdd_date2 = Column(DATE) # 最大回撤结束时间
+    mdd_lens = Column(Integer) # 最大回撤区间持续时间
+    ret_over_mdd = Column(DOUBLE(asdecimal=False)) # Calmar 年化收益除以最大回撤
+    last_mv_diff = Column(DOUBLE(asdecimal=False)) # 末期市值增量
+    last_increase_rate = Column(DOUBLE(asdecimal=False)) # 末期涨幅
+    worst_3m_ret = Column(DOUBLE(asdecimal=False)) # 最差三月收益
+    worst_6m_ret = Column(DOUBLE(asdecimal=False)) # 最差六月收益
+    recent_drawdown = Column(DOUBLE(asdecimal=False)) # 最近回撤
+    recent_mdd_date1 = Column(DATE) # 最近回撤开始时间
+    downside_std = Column(DOUBLE(asdecimal=False)) # 下行风险
+    var = Column(DOUBLE(asdecimal=False)) # 风险价值VaR
+    cvar = Column(DOUBLE(asdecimal=False)) # 条件风险价值 CVaR
+    raise_month_num = Column(Integer) # 上涨月份数
+    drop_month_num = Column(Integer) # 下跌月份数
+    mdd_recover = Column(DOUBLE(asdecimal=False)) # 最大回撤恢复
+    mdd_recover_date1 = Column(DATE) # 最大回撤恢复开始时间
+    mdd_recover_date2 = Column(DATE) # 最大回测恢复结束时间
+    mdd_recover_lens = Column(Integer) # 最大回测哈恢复天数
+    win_rate_0_period = Column(DOUBLE(asdecimal=False)) # 设定周期对零胜率
+    nav_density = Column(DOUBLE(asdecimal=False)) # 净值密度
+    nav_type = Column(CHAR(20)) # 净值类型
+    w1_end_date = Column(DATE) # 近一周结束时间
+    w1_begin_date = Column(DATE) # 近一周开始时间
+
+class PfIndicatorWithBenchmark(Base):
+    '''基金评价指标'''
+
+    __tablename__ = 'pf_indicator_with_benchmark'
+    pf_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    period = Column(Integer, primary_key=True) # 因子计算时间范围
+    index_id = Column(CHAR(10), primary_key=True) # 指数ID
+
+    alpha = Column(DOUBLE(asdecimal=False)) # 超额收益
+    beta = Column(DOUBLE(asdecimal=False)) # 风险暴露
+    track_err = Column(DOUBLE(asdecimal=False)) # 跟踪误差
+    ir = Column(DOUBLE(asdecimal=False)) # 信息比率
+    alpha_cl = Column(DOUBLE(asdecimal=False)) # 择股收益
+    beta_cl = Column(DOUBLE(asdecimal=False)) # 择时收益
+    treynor = Column(DOUBLE(asdecimal=False)) # 特雷诺
+    win_rate = Column(DOUBLE(asdecimal=False)) # 对基准胜率
+    win_rate_0 = Column(DOUBLE(asdecimal=False)) # 对零胜率
+    continue_value = Column(DOUBLE(asdecimal=False)) # 业绩持续性
+    win_rate_weekly = Column(DOUBLE(asdecimal=False)) # 周度对基准胜率
+    win_rate_0_weekly = Column(DOUBLE(asdecimal=False)) # 周度对零胜率
+    win_rate_monthly = Column(DOUBLE(asdecimal=False)) # 月度对基准胜率
+    win_rate_0_monthly = Column(DOUBLE(asdecimal=False)) # 月度对零胜率
+    excess_mdd = Column(DOUBLE(asdecimal=False)) # 超额收益最大回撤
+    excess_mdd_date1 = Column(DATE) # 超额收益最大回撤开始日
+    excess_mdd_date2 = Column(DATE) # 超额收益最大回撤结束日
+    excess_mdd_lens = Column(Integer) # 超额收益最大回撤持续时间
+    up_capture = Column(DOUBLE(asdecimal=False)) # 向上捕捉率
+    down_capture = Column(DOUBLE(asdecimal=False)) # 向下捕捉率
+    not_system_risk = Column(DOUBLE(asdecimal=False)) # 非系统性风险
+    corr = Column(DOUBLE(asdecimal=False)) # 相关性
+    sortino = Column(DOUBLE(asdecimal=False)) # 索提诺
+    skew = Column(DOUBLE(asdecimal=False)) # 偏度
+    kurtosis = Column(DOUBLE(asdecimal=False)) # 峰度
+    total_relative_ret = Column(DOUBLE(asdecimal=False)) # 相对全部收益
\ No newline at end of file
