@@ -1050,13 +1050,21 @@ class CalculatorBase:
 
     @staticmethod
     def get_nav_type(values, dates):
-        from ..data.api.basic import BasicDataApi
+        import json
+        import requests
         sr = pd.Series(values, index=dates).sort_index()
         tds = pd.to_datetime(sr.index)
         tds = [_.date() for _ in tds]
         sr.index = tds
-        dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).set_index('datetime')
-        sr_daily = sr.reindex(dts.index)
+        b_d = sr.index[0]
+        e_d = sr.index[-1]
+        url = 'http://69.231.155.101:8006/api/v1/basic/trade_dates'
+        response = requests.get(url)    
+        dts = json.loads(response._content)['data']['datetime']
+        dts = pd.to_datetime(dts)
+        dts = np.array([i.date() for i in dts])
+        dts = dts[(dts>=b_d) & (dts<=e_d)].tolist()
+        sr_daily = sr.reindex(dts)
         sr_week = CalculatorBase.data_resample_weekly_nav(df=sr_daily)
         sr_month = CalculatorBase.data_resample_monthly_nav(df=sr_daily)
 
