@@ -218,6 +218,16 @@ class WechatBot(object):
         markdown_content += f'\n>**err msg:** {err_msg}'
         self.send(markdown_content)
 
+    def send_hedge_and_product_nav_update(self, manager_id: str, r1: pd.DataFrame, r2: pd.DataFrame):
+        if r1 is not None:
+            markdown_content = f'#### <font color=\"warning\">{manager_id} 底层资产净值更新</font>'
+            markdown_content += r1.to_markdown(tablefmt="grid")
+            self.send(markdown_content, webhook=self._wechat_err_msg_webhook)
+        if r2 is not None:
+            markdown_content = f'#### <font color=\"warning\">{manager_id} 产品净值更新</font>'
+            markdown_content += r2.to_markdown(tablefmt="grid")
+            self.send(markdown_content, webhook=self._wechat_err_msg_webhook)
+
     def send_research_data_update(self, tag: str, datas: Dict[str, int]):
         markdown_content = f'#### 研究数据({tag})更新成功({len(datas.keys())})'
         for k, v in datas.items():
